.. _all-salt.grains:

==============
grains modules
==============

.. currentmodule:: salt.grains

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    chronos
    cimc
    core
    disks
    esxi
    extra
    fibre_channel
    fx2
    iscsi
    junos
    lvm
    marathon
    mdadm
    mdata
    metadata
    metadata_azure
    metadata_gce
    minion_process
    napalm
    nvme
    nxos
    opts
    panos
    pending_reboot
    philips_hue
    rest_sample
    smartos
    ssh_sample
    zfs
